@@ -16,7 +16,7 @@ from pprint import pprint
 # The Confuse library is awesome.
 import confuse
 
-DEBUG = False  # TODO: set to False :P
+DEBUG = False  # TODO: add humed argparse and implement --debug
 
 # hume is VERY related to logs
 # better /var/humed/humed.sqlite3 ?
@@ -26,7 +26,7 @@ if DEBUG:
 
 # Basic list of TRANSFER_METHODS
 # We extend TRANSFER_METHODS by testing for optional modules
-TRANSFER_METHODS = ['syslog', 'remote_syslog', 'slack', 'kant']  # TODO: kant will be our own
+TRANSFER_METHODS = ['syslog', 'rsyslog', 'slack', 'kant']  # TODO: kant will be our own
 
 # availability test for logstash (see optional_requirements.txt)
 try:
@@ -47,7 +47,7 @@ else:
 config_template = {  # TODO: add debug. check confuse.Bool()
     'endpoint': confuse.String(),
     'transfer_method': confuse.OneOf(TRANSFER_METHODS),
-    'remote_syslog': {
+    'rsyslog': {
         'server': confuse.String(),
         'proto': confuse.OneOf(['tcp','udp']),
         'port': confuse.Integer(),
@@ -80,10 +80,10 @@ class Humed():
                                             port,
                                             database_path='logstash.db'))
         # We will replace this with a plugin-oriented approach ASAP
-        elif self.transfer_method is 'remote_syslog':
-            server = self.config['remote_syslog']['server'].get()
-            port = self.config['remote_syslog']['port'].get()
-            proto = self.config['remote_syslog']['proto'].get()
+        elif self.transfer_method is 'rsyslog':
+            server = self.config['rsyslog']['server'].get()
+            port = self.config['rsyslog']['port'].get()
+            proto = self.config['rsyslog']['proto'].get()
             sa = (server,port)
             if proto is 'udp':
                 self.logger.addHandler(SysLogHandler(address=sa,
@@ -169,7 +169,7 @@ class Humed():
                 ret = self.logstash(item=item)
             elif self.transfer_method == 'syslog':
                 ret = self.syslog(item=item)  # using std SysLogHandler
-            elif self.transfer_method == 'remote_syslog':
+            elif self.transfer_method == 'rsyslog':
                 ret = self.syslog(item=item)  # using std SysLogHandler
             elif self.transfer_method == 'slack':
                 ret = self.slack(item=item)
@@ -187,7 +187,8 @@ class Humed():
         except Exception as ex:
             return(False)  # FIX: malformed json at this stage? mmm
         hume = humepkt['hume']
-        pprint(hume)
+        if DEBUG:
+            pprint(hume)
         level = hume['level']
         tags = hume['tags']
         task = hume['task']
@@ -353,7 +354,7 @@ class Humed():
 
     def run(self):
         # Humed main loop
-        sock = zmq.Context().socket(zmq.PULL)
+        sock = zmq.Context().socket(zmq.REP)
         # print("Binding to '{}'".format(self.endpoint))
         sock.bind(self.endpoint)
         # 2a - Await hume message over zmp
@@ -364,10 +365,12 @@ class Humed():
             except Exception as ex:
                 print(ex)
                 print('Cannot json-loads the received message. notgood')
+                sock.send_string('Invalid JSON message')
             except KeyboardInterrupt as kb:
                 print('CTRL-C called, exiting now')
                 sys.exit(255)
             else:
+                sock.send_string('OK')
                 self.add_transfer(hume)
                 self.process_transfers()
         # TODO: 2c - log errors and rowids
@@ -379,9 +382,9 @@ def main():
     config = confuse.Configuration('humed')
     # Config defaults
     config['endpoint'] = 'tcp://127.0.0.1:198'
-    config['remote_syslog']['server'] = 'localhost'
-    config['remote_syslog']['proto'] = 'udp'
-    config['remote_syslog']['port'] = 514
+    config['rsyslog']['server'] = 'localhost'
+    config['rsyslog']['proto'] = 'udp'
+    config['rsyslog']['port'] = 514
     parser = argparse.ArgumentParser()
     config['debug'] = DEBUG
     parser.add_argument('--debug',
@@ -393,16 +396,17 @@ def main():
     except Exception as ex:
         print('Humed: Config file validation error: {}'.format(ex))
         sys.exit(2)
-    print('-----[ CONFIG DUMP ]-----')
-    print(config.dump())
-    print('Available Transfer Methods: {}'.format(TRANSFER_METHODS))
-    print('---[ CONFIG DUMP END ]---')
+    if DEBUG:
+        print('-----[ CONFIG DUMP ]-----')
+        print(config.dump())
+        print('Available Transfer Methods: {}'.format(TRANSFER_METHODS))
+        print('---[ CONFIG DUMP END ]---')
     try:
         with pidfile.PIDFile():
-            print('Process started')
+            if DEBUG:
+                print('Process started')
     except pidfile.AlreadyRunningError:
-        print('Already running.')
-        print('Exiting')
+        print('Humed is already running. Exiting...')
         sys.exit(1)
 
     # Initialize Stuff - configuration will be tested in Humed __init__
@@ -411,7 +415,8 @@ def main():
     # TODO: Tell systemd we are ready
     # systemd.daemon.notify('READY=1')
 
-    print('Ready. serving...')
+    if DEBUG:
+        print('Ready. serving...')
     humed.run()
 
 
